@@ -334,8 +334,7 @@ class SOAP_Transport_HTTP extends SOAP_Transport
             // SOAP faults.
             $this->_parseHeaders($match[1]);
 
-            list($protocol, $code, $msg) = sscanf($this->result_headers[0],
-                                                  '%s %s %s');
+            list(, $code, $msg) = sscanf($this->result_headers[0], '%s %s %s');
             unset($this->result_headers[0]);
 
             switch($code) {
@@ -404,7 +403,7 @@ class SOAP_Transport_HTTP extends SOAP_Transport
     }
 
     /**
-     * Creates an HTTP request, including headers, for th eoutgoing request.
+     * Creates an HTTP request, including headers, for the outgoing request.
      *
      * @access private
      *
@@ -446,6 +445,8 @@ class SOAP_Transport_HTTP extends SOAP_Transport
         $this->headers['Content-Type'] = "text/xml; charset=$this->encoding";
         $this->headers['Content-Length'] = strlen($msg);
         $this->headers['SOAPAction'] = '"' . $action . '"';
+        $this->headers['Connection'] = 'close';
+
         if (isset($options['headers'])) {
             $this->headers = array_merge($this->headers, $options['headers']);
         }
@@ -559,8 +560,12 @@ class SOAP_Transport_HTTP extends SOAP_Transport
         if (!isset($options['soapaction'])) {
             $options['soapaction'] = '';
         }
+        if (!isset($options['headers']['Content-Type'])) {
+           $options['headers']['Content-Type'] = 'text/xml';
+        }
         curl_setopt($ch, CURLOPT_HTTPHEADER,
-                    array('Content-Type: text/xml;charset=' . $this->encoding,
+                    array('Content-Type: ' . $options['headers']['Content-Type']
+                         . ';charset=' . $this->encoding,
                           'SOAPAction: "' . $options['soapaction'] . '"'));
         curl_setopt($ch, CURLOPT_USERAGENT,
                     $this->_userAgent);
