@@ -209,10 +209,8 @@ class SOAP_WSDL extends SOAP_Base
      * Fills the WSDL array tree with data from a WSDL file.
      *
      * @param string $wsdl_uri  URL to WSDL file.
-     * @param array $proxy      Contains options for HTTP_Request class
-     *                          @see HTTP_Request.
      */
-    function parseURL($wsdl_uri, $proxy = array())
+    function parseURL($wsdl_uri)
     {
         $parser =& new $this->wsdlParserClass($wsdl_uri, $this, $this->docs);
 
@@ -380,7 +378,7 @@ class SOAP_WSDL extends SOAP_Base
         }
 
         // Overloading lowercases function names :(
-        foreach ($this->services[$this->service]['ports'] as $port => $portAttrs) {
+        foreach ($this->services[$this->service]['ports'] as $portAttrs) {
             foreach (array_keys($this->bindings[$portAttrs['binding']]['operations']) as $op) {
                 if (strcasecmp($op, $operation) == 0) {
                     $operation = $op;
@@ -415,7 +413,7 @@ class SOAP_WSDL extends SOAP_Base
                 $checkmessages = array();
                 // Find what messages use this datatype.
                 foreach ($this->messages as $messagename => $message) {
-                    foreach ($message as $partname => $part) {
+                    foreach ($message as $part) {
                         if ($part['type'] == $datatype) {
                             $checkmessages[] = $messagename;
                             break;
@@ -423,8 +421,7 @@ class SOAP_WSDL extends SOAP_Base
                     }
                 }
                 // Find the operation that uses this message.
-                $dataHandler = null;
-                foreach($this->portTypes as $portname => $porttype) {
+                foreach($this->portTypes as $porttype) {
                     foreach ($porttype as $opname => $opinfo) {
                         foreach ($checkmessages as $messagename) {
                             if ($opinfo['input']['message'] == $messagename) {
@@ -533,7 +530,7 @@ class SOAP_WSDL extends SOAP_Base
                 $comments .= "        // {$_argtype['type']} may require attributes, refer to the WSDL for more info.\n";
             }
             $comments .= "        \${$attrname}['xmlns'] = '{$this->namespaces[$_argtype['namespace']]}';\n";
-            $comments .= "        \${$_argtype['type']} =& new SOAP_Value('{$_argtype['type']}', false, \${$_argtype['type']}, \$$attrname);\n";
+            $comments .= "        \${$_argtype['type']} = new SOAP_Value('{$_argtype['type']}', false, \${$_argtype['type']}, \$$attrname);\n";
             $this->_addArg($args, $argarray, $_argtype['type']);
             if (isset($el['type']) &&
                 isset($this->complexTypes[$tns][$el['type']]['attribute'])) {
@@ -544,13 +541,13 @@ class SOAP_WSDL extends SOAP_Base
             }
         } elseif (isset($el['elements'])) {
             foreach ($el['elements'] as $ename => $element) {
-                $comments .= "        \$$ename =& new SOAP_Value('{{$this->namespaces[$element['namespace']]}}$ename', '" .
+                $comments .= "        \$$ename = new SOAP_Value('{{$this->namespaces[$element['namespace']]}}$ename', '" .
                     (isset($element['type']) ? $element['type'] : false) .
                     "', \$$ename);\n";
                 $this->_addArg($args, $argarray, $ename);
             }
         } else {
-            $comments .= "        \$$_argname =& new SOAP_Value('{{$this->namespaces[$tns]}}$_argname', '{$el['type']}', \$$_argname);\n";
+            $comments .= "        \$$_argname = new SOAP_Value('{{$this->namespaces[$tns]}}$_argname', '{$el['type']}', \$$_argname);\n";
             $this->_addArg($args, $argarray, $_argname);
         }
 
@@ -567,7 +564,7 @@ class SOAP_WSDL extends SOAP_Base
                 $comments .= "        // $_argname may require attributes, refer to wsdl for more info\n";
             }
             $wrapname = '{' . $this->namespaces[$_argtype['namespace']].'}' . $_argtype['type'];
-            $comments .= "        \$$_argname =& new SOAP_Value('$_argname', '$wrapname', \$$_argname);\n";
+            $comments .= "        \$$_argname = new SOAP_Value('$_argname', '$wrapname', \$$_argname);\n";
         }
 
         $this->_addArg($args, $argarray, $_argname);
@@ -678,7 +675,6 @@ class SOAP_WSDL extends SOAP_Base
                             // The type or element refered to is used for
                             // parameters.
                             $elattrs = null;
-                            $element = $_argtype['element'];
                             $el = $this->elements[$_argtype['namespace']][$_argtype['type']];
 
                             if ($el['complex']) {
@@ -699,7 +695,7 @@ class SOAP_WSDL extends SOAP_Base
                             }
                             if ($el['complex'] && $argarray) {
                                 $wrapname = '{' . $this->namespaces[$_argtype['namespace']].'}' . $el['name'];
-                                $comments .= "        \${$el['name']} =& new SOAP_Value('$wrapname', false, \$v = array($argarray));\n";
+                                $comments .= "        \${$el['name']} = new SOAP_Value('$wrapname', false, \$v = array($argarray));\n";
                                 $argarray = "'{$el['name']}' => \${$el['name']}";
                             }
                         } else {
@@ -861,7 +857,7 @@ class SOAP_WSDL extends SOAP_Base
         if ($name && $type) {
             // XXX TODO:
             // look up the name in the wsdl and validate the type.
-            foreach ($this->complexTypes as $ns => $types) {
+            foreach ($this->complexTypes as $types) {
                 if (isset($types[$type])) {
                     if (isset($types[$type]['type'])) {
                         list($arraytype_ns, $arraytype, $array_depth) = isset($types[$type]['arrayType'])
@@ -1192,7 +1188,7 @@ class SOAP_WSDL_Parser extends SOAP_Base
     function startElement($parser, $name, $attrs)
     {
         // Get element prefix.
-        $qname =& new QName($name);
+        $qname = new QName($name);
         if ($qname->ns) {
             $ns = $qname->ns;
             if ($ns && ((!$this->tns && strcasecmp($qname->name, 'definitions') == 0) || $ns == $this->tns)) {
@@ -1240,7 +1236,7 @@ class SOAP_WSDL_Parser extends SOAP_Base
                     }
                     $this->wsdl->complexTypes[$this->schema][$this->currentComplexType] = $attrs;
                     if (array_key_exists('base', $attrs)) {
-                        $qn =& new QName($attrs['base']);
+                        $qn = new QName($attrs['base']);
                         $this->wsdl->complexTypes[$this->schema][$this->currentComplexType]['type'] = $qn->name;
                         $this->wsdl->complexTypes[$this->schema][$this->currentComplexType]['namespace'] = $qn->ns;
                     } else {
@@ -1254,7 +1250,7 @@ class SOAP_WSDL_Parser extends SOAP_Base
 
             case 'element':
                 if (isset($attrs['type'])) {
-                    $qn =& new QName($attrs['type']);
+                    $qn = new QName($attrs['type']);
                     $attrs['type'] = $qn->name;
                     if ($qn->ns && array_key_exists($qn->ns, $this->wsdl->namespaces)) {
                         $attrs['namespace'] = $qn->ns;
@@ -1268,7 +1264,7 @@ class SOAP_WSDL_Parser extends SOAP_Base
                 }
 
                 if (isset($attrs['ref'])) {
-                    $qn =& new QName($attrs['ref']);
+                    $qn = new QName($attrs['ref']);
                     $this->currentElement = $qn->name;
                 } else {
                     $this->currentElement = $attrs['name'];
@@ -1303,7 +1299,7 @@ class SOAP_WSDL_Parser extends SOAP_Base
             case 'restriction':
                 if ($this->schemaStatus == 'complexType') {
                     if (!empty($attrs['base'])) {
-                        $qn =& new QName($attrs['base']);
+                        $qn = new QName($attrs['base']);
                         $this->wsdl->complexTypes[$this->schema][$this->currentComplexType]['type'] = $qn->name;
 
                         // Types that extend from other types aren't
@@ -1348,10 +1344,10 @@ class SOAP_WSDL_Parser extends SOAP_Base
                         $this->wsdl->complexTypes[$this->schema][$this->currentComplexType]['attribute'][$attrs['name']] = $attrs;
                     } else {
                         if (isset($attrs['ref'])) {
-                            $q =& new QName($attrs['ref']);
+                            $q = new QName($attrs['ref']);
                             foreach ($attrs as $k => $v) {
                                 if ($k != 'ref' && strstr($k, $q->name)) {
-                                    $vq =& new QName($v);
+                                    $vq = new QName($v);
                                     if ($q->name == 'arrayType') {
                                         $this->wsdl->complexTypes[$this->schema][$this->currentComplexType][$q->name] = $vq->name. $vq->arrayInfo;
                                         $this->wsdl->complexTypes[$this->schema][$this->currentComplexType]['type'] = 'Array';
@@ -1376,9 +1372,9 @@ class SOAP_WSDL_Parser extends SOAP_Base
             case 'part':
                 $qn = null;
                 if (isset($attrs['type'])) {
-                    $qn =& new QName($attrs['type']);
+                    $qn = new QName($attrs['type']);
                 } elseif (isset($attrs['element'])) {
-                    $qn =& new QName($attrs['element']);
+                    $qn = new QName($attrs['element']);
                 }
                 if ($qn) {
                     $attrs['type'] = $qn->name;
@@ -1417,7 +1413,7 @@ class SOAP_WSDL_Parser extends SOAP_Base
                         $this->wsdl->portTypes[$this->currentPortType][$this->currentOperation][$name] = $attrs;
                     }
                     if (array_key_exists('message', $attrs)) {
-                        $qn =& new QName($attrs['message']);
+                        $qn = new QName($attrs['message']);
                         $this->wsdl->portTypes[$this->currentPortType][$this->currentOperation][$name]['message'] = $qn->name;
                         $this->wsdl->portTypes[$this->currentPortType][$this->currentOperation][$name]['namespace'] = $qn->ns;
                     }
@@ -1628,7 +1624,7 @@ class SOAP_WSDL_Parser extends SOAP_Base
                 $this->currentPort = $attrs['name'];
                 $this->wsdl->services[$this->currentService]['ports'][$this->currentPort] = $attrs;
                 // XXX hack to deal with binding namespaces
-                $qn =& new QName($attrs['binding']);
+                $qn = new QName($attrs['binding']);
                 $this->wsdl->services[$this->currentService]['ports'][$this->currentPort]['binding'] = $qn->name;
                 $this->wsdl->services[$this->currentService]['ports'][$this->currentPort]['namespace'] = $qn->ns;
                 break;
@@ -1731,7 +1727,7 @@ class SOAP_WSDL_Parser extends SOAP_Base
             }
             $this->status = 'binding';
             $this->currentBinding = $attrs['name'];
-            $qn =& new QName($attrs['type']);
+            $qn = new QName($attrs['type']);
             $this->wsdl->bindings[$this->currentBinding]['type'] = $qn->name;
             $this->wsdl->bindings[$this->currentBinding]['namespace'] = $qn->ns;
             break;
@@ -1750,7 +1746,7 @@ class SOAP_WSDL_Parser extends SOAP_Base
             $this->wsdl->definition = $attrs;
             foreach ($attrs as $key => $value) {
                 if (strstr($key, 'xmlns:') !== false) {
-                    $qn =& new QName($key);
+                    $qn = new QName($key);
                     // XXX need to refactor ns handling.
                     $this->wsdl->namespaces[$qn->name] = $value;
                     $this->wsdl->ns[$value] = $qn->name;
@@ -1965,15 +1961,21 @@ class SOAP_WSDL_ObjectParser extends SOAP_Base
      */
     var $wsdl = null;
 
-    /** Constructor
+    /**
+     * Constructor.
      *
-     * @param  $objects Reference to the object or array of objects to parse
-     * @param  $wsdl Reference to the SOAP_WSDL object to populate
-     * @param  $targetNamespace The target namespace of schema types etc.
-     * @param  $service_name Name of the WSDL <service>
-     * @param  $service_desc Optional description of the WSDL <service>
+     * @param object|array $objects    Reference to the object or array of
+     *                                 objects to parse.
+     * @param SOAP_WSDL $wsdl          Reference to the SOAP_WSDL object to
+     *                                 populate.
+     * @param string $targetNamespace  The target namespace of schema types
+     *                                 etc.
+     * @param string $service_name     Name of the WSDL <service>.
+     * @param string $service_desc     Optional description of the WSDL
+     *                                 <service>.
      */
-    function SOAP_WSDL_ObjectParser(&$objects, &$wsdl, $targetNamespace, $service_name, $service_desc = '')
+    function SOAP_WSDL_ObjectParser(&$objects, &$wsdl, $targetNamespace,
+                                    $service_name, $service_desc = '')
     {
         parent::SOAP_Base('WSDLOBJECTPARSER');
 
@@ -1986,11 +1988,14 @@ class SOAP_WSDL_ObjectParser extends SOAP_Base
         $wsdl_ref = (is_array($objects)? $objects : array(&$objects));
 
         foreach ($wsdl_ref as $ref_item) {
-            if (!is_object($ref_item))
-                return $this->_raiseSoapFault('Invalid web service object passed to object parser', 'urn:' . get_class($object));
+            if (!is_object($ref_item)) {
+                $this->_raiseSoapFault('Invalid web service object passed to object parser');
+                continue;
+            }
 
-            if ($this->_parse($ref_item, $targetNamespace, $service_name) != true)
+            if (!$this->_parse($ref_item, $targetNamespace, $service_name)) {
                 break;
+            }
         }
 
         // Build bindings from abstract data.
@@ -2163,24 +2168,25 @@ class SOAP_WSDL_ObjectParser extends SOAP_Base
     }
 
     /**
-     * Take all the abstract WSDL data and build concrete bindings and
+     * Takes all the abstract WSDL data and builds concrete bindings and
      * services (destructive).
      *
-     * XXX Current implementation discards $service_desc.
-     *
-     * @param  $schemaNamespace Namespace for types etc.
-     * @param  $service_name Name of the WSDL <service>
-     * @param  $service_desc Optional description of the WSDL <service>
      * @access private
+     * @todo Current implementation discards $service_desc.
+     *
+     * @param string $schemaNamespace  Namespace for types etc.
+     * @param string $service_name     Name of the WSDL <service>.
+     * @param string $service_desc     Optional description of the WSDL
+     *                                 <service>.
      */
-    function _generateBindingsAndServices($schemaNamespace, $service_name, $service_desc = '')
+    function _generateBindingsAndServices($schemaNamespace, $service_name,
+                                          $service_desc = '')
     {
         // Populate tree with bindings information
         // XXX Current implementation only supports one binding that
         // matches the single portType and all of its operations.
         // XXX Is this the correct use of $schemaNamespace here?
         // *** <wsdl:binding> ***
-
         $this->wsdl->bindings[$service_name . 'Binding'] = array(
                 'type' => $service_name . 'Port',
                 'namespace' => $this->tnsPrefix,
